"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import unittest

import cryptoapis
from cryptoapis.api.informative_api import InformativeApi  # noqa: E501


class TestInformativeApi(unittest.TestCase):
    """InformativeApi unit test stubs"""

    def setUp(self):
        self.api = InformativeApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_wallet_asset_details(self):
        """Test case for get_wallet_asset_details

        Get Wallet Asset Details  # noqa: E501
        """
        pass

    def test_list_receiving_addresses(self):
        """Test case for list_receiving_addresses

        List Receiving Addresses  # noqa: E501
        """
        pass

    def test_list_supported_tokens(self):
        """Test case for list_supported_tokens

        List Supported Tokens  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.list_transactions_by_address_ribsd2_script_sig import ListTransactionsByAddressRIBSD2ScriptSig
globals()['ListTransactionsByAddressRIBSD2ScriptSig'] = ListTransactionsByAddressRIBSD2ScriptSig
from cryptoapis.model.list_transactions_by_address_ribsd2_vin import ListTransactionsByAddressRIBSD2Vin


class TestListTransactionsByAddressRIBSD2Vin(unittest.TestCase):
    """ListTransactionsByAddressRIBSD2Vin unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListTransactionsByAddressRIBSD2Vin(self):
        """Test ListTransactionsByAddressRIBSD2Vin"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListTransactionsByAddressRIBSD2Vin()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.list_xrp_ripple_transactions_by_block_height_ri_fee import ListXRPRippleTransactionsByBlockHeightRIFee
from cryptoapis.model.list_xrp_ripple_transactions_by_block_height_ri_offer import ListXRPRippleTransactionsByBlockHeightRIOffer
from cryptoapis.model.list_xrp_ripple_transactions_by_block_height_ri_receive import ListXRPRippleTransactionsByBlockHeightRIReceive
from cryptoapis.model.list_xrp_ripple_transactions_by_block_height_ri_recipients import ListXRPRippleTransactionsByBlockHeightRIRecipients
from cryptoapis.model.list_xrp_ripple_transactions_by_block_height_ri_senders import ListXRPRippleTransactionsByBlockHeightRISenders
from cryptoapis.model.list_xrp_ripple_transactions_by_block_height_ri_value import ListXRPRippleTransactionsByBlockHeightRIValue
globals()['ListXRPRippleTransactionsByBlockHeightRIFee'] = ListXRPRippleTransactionsByBlockHeightRIFee
globals()['ListXRPRippleTransactionsByBlockHeightRIOffer'] = ListXRPRippleTransactionsByBlockHeightRIOffer
globals()['ListXRPRippleTransactionsByBlockHeightRIReceive'] = ListXRPRippleTransactionsByBlockHeightRIReceive
globals()['ListXRPRippleTransactionsByBlockHeightRIRecipients'] = ListXRPRippleTransactionsByBlockHeightRIRecipients
globals()['ListXRPRippleTransactionsByBlockHeightRISenders'] = ListXRPRippleTransactionsByBlockHeightRISenders
globals()['ListXRPRippleTransactionsByBlockHeightRIValue'] = ListXRPRippleTransactionsByBlockHeightRIValue
from cryptoapis.model.list_xrp_ripple_transactions_by_block_height_ri import ListXRPRippleTransactionsByBlockHeightRI


class TestListXRPRippleTransactionsByBlockHeightRI(unittest.TestCase):
    """ListXRPRippleTransactionsByBlockHeightRI unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListXRPRippleTransactionsByBlockHeightRI(self):
        """Test ListXRPRippleTransactionsByBlockHeightRI"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListXRPRippleTransactionsByBlockHeightRI()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from cryptoapis.api_client import ApiClient, Endpoint as _Endpoint
from cryptoapis.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from cryptoapis.model.create_coins_transaction_request_from_address_r import CreateCoinsTransactionRequestFromAddressR
from cryptoapis.model.create_coins_transaction_request_from_address_rb import CreateCoinsTransactionRequestFromAddressRB
from cryptoapis.model.create_coins_transaction_request_from_wallet_r import CreateCoinsTransactionRequestFromWalletR
from cryptoapis.model.create_coins_transaction_request_from_wallet_rb import CreateCoinsTransactionRequestFromWalletRB
from cryptoapis.model.create_tokens_transaction_request_from_address_r import CreateTokensTransactionRequestFromAddressR
from cryptoapis.model.create_tokens_transaction_request_from_address_rb import CreateTokensTransactionRequestFromAddressRB
from cryptoapis.model.feature_mainnets_not_allowed_for_plan import FeatureMainnetsNotAllowedForPlan
from cryptoapis.model.insufficient_credits import InsufficientCredits
from cryptoapis.model.invalid_api_key import InvalidApiKey
from cryptoapis.model.invalid_pagination import InvalidPagination
from cryptoapis.model.invalid_request_body_structure import InvalidRequestBodyStructure
from cryptoapis.model.request_limit_reached import RequestLimitReached
from cryptoapis.model.unexpected_server_error import UnexpectedServerError
from cryptoapis.model.unsupported_media_type import UnsupportedMediaType
from cryptoapis.model.wallet_as_a_service_no_deposit_addresses_found import WalletAsAServiceNoDepositAddressesFound
from cryptoapis.model.wallet_as_a_service_token_not_supported import WalletAsAServiceTokenNotSupported
from cryptoapis.model.wallet_as_a_service_wallet_balance_not_enough import WalletAsAServiceWalletBalanceNotEnough


class TransactionsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        def __create_coins_transaction_request_from_address(
            self,
            address,
            wallet_id,
            blockchain="ethereum",
            network="mainnet",
            **kwargs
        ):
            """Create Coins Transaction Request from Address  # noqa: E501

            Through this endpoint users can create a new single transaction request from one address to another.  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.create_coins_transaction_request_from_address(address, wallet_id, blockchain="ethereum", network="mainnet", async_req=True)
            >>> result = thread.get()

            Args:
                address (str): Defines the specific source address for the transaction.
                wallet_id (str): Represents the sender's specific and unique Wallet ID of the sender.
                blockchain (str): Represents the specific blockchain protocol name, e.g. Ethereum, Bitcoin, etc.. defaults to "ethereum", must be one of ["ethereum"]
                network (str): Represents the name of the blockchain network used; blockchain networks are usually identical as technology and software, but they differ in data, e.g. - \"mainnet\" is the live network with actual data while networks like \"testnet\", \"ropsten\", \"rinkeby\" are test networks.. defaults to "mainnet", must be one of ["mainnet"]

            Keyword Args:
                context (str): In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. `context` is specified by the user.. [optional]
                create_coins_transaction_request_from_address_rb (CreateCoinsTransactionRequestFromAddressRB): [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                CreateCoinsTransactionRequestFromAddressR
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['address'] = \
                address
            kwargs['blockchain'] = \
                blockchain
            kwargs['network'] = \
                network
            kwargs['wallet_id'] = \
                wallet_id
            return self.call_with_http_info(**kwargs)

        self.create_coins_transaction_request_from_address = _Endpoint(
            settings={
                'response_type': (CreateCoinsTransactionRequestFromAddressR,),
                'auth': [
                    'ApiKey'
                ],
                'endpoint_path': '/wallet-as-a-service/wallets/{walletId}/{blockchain}/{network}/addresses/{address}/transaction-requests',
                'operation_id': 'create_coins_transaction_request_from_address',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'address',
                    'blockchain',
                    'network',
                    'wallet_id',
                    'context',
                    'create_coins_transaction_request_from_address_rb',
                ],
                'required': [
                    'address',
                    'blockchain',
                    'network',
                    'wallet_id',
                ],
                'nullable': [
                ],
                'enum': [
                    'blockchain',
                    'network',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('blockchain',): {

                        "ETHEREUM": "ethereum"
                    },
                    ('network',): {

                        "MAINNET": "mainnet"
                    },
                },
                'openapi_types': {
                    'address':
                        (str,),
                    'blockchain':
                        (str,),
                    'network':
                        (str,),
                    'wallet_id':
                        (str,),
                    'context':
                        (str,),
                    'create_coins_transaction_request_from_address_rb':
                        (CreateCoinsTransactionRequestFromAddressRB,),
                },
                'attribute_map': {
                    'address': 'address',
                    'blockchain': 'blockchain',
                    'network': 'network',
                    'wallet_id': 'walletId',
                    'context': 'context',
                },
                'location_map': {
                    'address': 'path',
                    'blockchain': 'path',
                    'network': 'path',
                    'wallet_id': 'path',
                    'context': 'query',
                    'create_coins_transaction_request_from_address_rb': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__create_coins_transaction_request_from_address
        )

        def __create_coins_transaction_request_from_wallet(
            self,
            blockchain,
            network,
            wallet_id,
            **kwargs
        ):
            """Create Coins Transaction Request from Wallet  # noqa: E501

            Through this endpoint users can create a new transaction request from the entire Wallet instead from just a specific address. This endpoint can generate transactions from multiple to multiple addresses.    {warning}This is available **only** for UTXO-based protocols such as Bitcoin, Bitcoin Cash, Litecoin, etc. It **is not** available for Account-based protocols like Ethereum.{/warning}  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.create_coins_transaction_request_from_wallet(blockchain, network, wallet_id, async_req=True)
            >>> result = thread.get()

            Args:
                blockchain (str): Represents the specific blockchain protocol name, e.g. Ethereum, Bitcoin, etc.
                network (str): Represents the name of the blockchain network used; blockchain networks are usually identical as technology and software, but they differ in data, e.g. - \"mainnet\" is the live network with actual data while networks like \"testnet\", \"ropsten\", \"rinkeby\" are test networks.
                wallet_id (str): Represents the sender's specific and unique Wallet ID of the sender.

            Keyword Args:
                context (str): In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. `context` is specified by the user.. [optional]
                create_coins_transaction_request_from_wallet_rb (CreateCoinsTransactionRequestFromWalletRB): [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                CreateCoinsTransactionRequestFromWalletR
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['blockchain'] = \
                blockchain
            kwargs['network'] = \
                network
            kwargs['wallet_id'] = \
                wallet_id
            return self.call_with_http_info(**kwargs)

        self.create_coins_transaction_request_from_wallet = _Endpoint(
            settings={
                'response_type': (CreateCoinsTransactionRequestFromWalletR,),
                'auth': [
                    'ApiKey'
                ],
                'endpoint_path': '/wallet-as-a-service/wallets/{walletId}/{blockchain}/{network}/transaction-requests',
                'operation_id': 'create_coins_transaction_request_from_wallet',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'blockchain',
                    'network',
                    'wallet_id',
                    'context',
                    'create_coins_transaction_request_from_wallet_rb',
                ],
                'required': [
                    'blockchain',
                    'network',
                    'wallet_id',
                ],
                'nullable': [
                ],
                'enum': [
                    'blockchain',
                    'network',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('blockchain',): {

                        "BITCOIN": "bitcoin",
                        "BITCOIN-CASH": "bitcoin-cash",
                        "LITECOIN": "litecoin",
                        "DOGECOIN": "dogecoin",
                        "DASH": "dash"
                    },
                    ('network',): {

                        "MAINNET": "mainnet",
                        "TESTNET": "testnet"
                    },
                },
                'openapi_types': {
                    'blockchain':
                        (str,),
                    'network':
                        (str,),
                    'wallet_id':
                        (str,),
                    'context':
                        (str,),
                    'create_coins_transaction_request_from_wallet_rb':
                        (CreateCoinsTransactionRequestFromWalletRB,),
                },
                'attribute_map': {
                    'blockchain': 'blockchain',
                    'network': 'network',
                    'wallet_id': 'walletId',
                    'context': 'context',
                },
                'location_map': {
                    'blockchain': 'path',
                    'network': 'path',
                    'wallet_id': 'path',
                    'context': 'query',
                    'create_coins_transaction_request_from_wallet_rb': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__create_coins_transaction_request_from_wallet
        )

        def __create_tokens_transaction_request_from_address(
            self,
            address,
            wallet_id,
            blockchain="ethereum",
            network="mainnet",
            **kwargs
        ):
            """Create Tokens Transaction Request from Address  # noqa: E501

            Through this endpoint users can make a single token transaction.    {warning}This applies only to **fungible** tokens, **not** NFTs (non-fungible tokens).{/warning}  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.create_tokens_transaction_request_from_address(address, wallet_id, blockchain="ethereum", network="mainnet", async_req=True)
            >>> result = thread.get()

            Args:
                address (str): Defines the specific source address for the transaction.
                wallet_id (str): Defines the unique ID of the Wallet.
                blockchain (str): Represents the specific blockchain protocol name, e.g. Ethereum, Bitcoin, etc.. defaults to "ethereum", must be one of ["ethereum"]
                network (str): Represents the name of the blockchain network used; blockchain networks are usually identical as technology and software, but they differ in data, e.g. - \"mainnet\" is the live network with actual data while networks like \"testnet\", \"ropsten\", \"rinkeby\" are test networks.. defaults to "mainnet", must be one of ["mainnet"]

            Keyword Args:
                context (str): In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. `context` is specified by the user.. [optional]
                create_tokens_transaction_request_from_address_rb (CreateTokensTransactionRequestFromAddressRB): [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                CreateTokensTransactionRequestFromAddressR
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['address'] = \
                address
            kwargs['blockchain'] = \
                blockchain
            kwargs['network'] = \
                network
            kwargs['wallet_id'] = \
                wallet_id
            return self.call_with_http_info(**kwargs)

        self.create_tokens_transaction_request_from_address = _Endpoint(
            settings={
                'response_type': (CreateTokensTransactionRequestFromAddressR,),
                'auth': [
                    'ApiKey'
                ],
                'endpoint_path': '/wallet-as-a-service/wallets/{walletId}/{blockchain}/{network}/addresses/{address}/token-transaction-requests',
                'operation_id': 'create_tokens_transaction_request_from_address',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'address',
                    'blockchain',
                    'network',
                    'wallet_id',
                    'context',
                    'create_tokens_transaction_request_from_address_rb',
                ],
                'required': [
                    'address',
                    'blockchain',
                    'network',
                    'wallet_id',
                ],
                'nullable': [
                ],
                'enum': [
                    'blockchain',
                    'network',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('blockchain',): {

                        "ETHEREUM": "ethereum"
                    },
                    ('network',): {

                        "MAINNET": "mainnet",
                        "ROPSTEN": "ropsten"
                    },
                },
                'openapi_types': {
                    'address':
                        (str,),
                    'blockchain':
                        (str,),
                    'network':
                        (str,),
                    'wallet_id':
                        (str,),
                    'context':
                        (str,),
                    'create_tokens_transaction_request_from_address_rb':
                        (CreateTokensTransactionRequestFromAddressRB,),
                },
                'attribute_map': {
                    'address': 'address',
                    'blockchain': 'blockchain',
                    'network': 'network',
                    'wallet_id': 'walletId',
                    'context': 'context',
                },
                'location_map': {
                    'address': 'path',
                    'blockchain': 'path',
                    'network': 'path',
                    'wallet_id': 'path',
                    'context': 'query',
                    'create_tokens_transaction_request_from_address_rb': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__create_tokens_transaction_request_from_address
        )



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import unittest

import cryptoapis
from cryptoapis.api.manage_subscriptions_api import ManageSubscriptionsApi  # noqa: E501


class TestManageSubscriptionsApi(unittest.TestCase):
    """ManageSubscriptionsApi unit test stubs"""

    def setUp(self):
        self.api = ManageSubscriptionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_blockchain_event_subscription(self):
        """Test case for delete_blockchain_event_subscription

        Delete Blockchain Event Subscription  # noqa: E501
        """
        pass

    def test_list_blockchain_events_subscriptions(self):
        """Test case for list_blockchain_events_subscriptions

        List Blockchain Events Subscriptions  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.new_confirmed_tokens_transactions_and_each_confirmation_rb_data import NewConfirmedTokensTransactionsAndEachConfirmationRBData
globals()['NewConfirmedTokensTransactionsAndEachConfirmationRBData'] = NewConfirmedTokensTransactionsAndEachConfirmationRBData
from cryptoapis.model.new_confirmed_tokens_transactions_and_each_confirmation_rb import NewConfirmedTokensTransactionsAndEachConfirmationRB


class TestNewConfirmedTokensTransactionsAndEachConfirmationRB(unittest.TestCase):
    """NewConfirmedTokensTransactionsAndEachConfirmationRB unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testNewConfirmedTokensTransactionsAndEachConfirmationRB(self):
        """Test NewConfirmedTokensTransactionsAndEachConfirmationRB"""
        # FIXME: construct object with mandatory attributes with example values
        # model = NewConfirmedTokensTransactionsAndEachConfirmationRB()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.list_hd_wallet_x_pub_y_pub_z_pub_transactions_ri_fee import ListHDWalletXPubYPubZPubTransactionsRIFee
from cryptoapis.model.list_hd_wallet_x_pub_y_pub_z_pub_transactions_ri_recipients import ListHDWalletXPubYPubZPubTransactionsRIRecipients
from cryptoapis.model.list_hd_wallet_x_pub_y_pub_z_pub_transactions_ri_senders import ListHDWalletXPubYPubZPubTransactionsRISenders
globals()['ListHDWalletXPubYPubZPubTransactionsRIFee'] = ListHDWalletXPubYPubZPubTransactionsRIFee
globals()['ListHDWalletXPubYPubZPubTransactionsRIRecipients'] = ListHDWalletXPubYPubZPubTransactionsRIRecipients
globals()['ListHDWalletXPubYPubZPubTransactionsRISenders'] = ListHDWalletXPubYPubZPubTransactionsRISenders
from cryptoapis.model.list_hd_wallet_x_pub_y_pub_z_pub_transactions_ri import ListHDWalletXPubYPubZPubTransactionsRI


class TestListHDWalletXPubYPubZPubTransactionsRI(unittest.TestCase):
    """ListHDWalletXPubYPubZPubTransactionsRI unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListHDWalletXPubYPubZPubTransactionsRI(self):
        """Test ListHDWalletXPubYPubZPubTransactionsRI"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListHDWalletXPubYPubZPubTransactionsRI()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_transaction_details_by_transaction_idribsd_script_pub_key import GetTransactionDetailsByTransactionIDRIBSDScriptPubKey
globals()['GetTransactionDetailsByTransactionIDRIBSDScriptPubKey'] = GetTransactionDetailsByTransactionIDRIBSDScriptPubKey
from cryptoapis.model.get_transaction_details_by_transaction_idribsd_vout import GetTransactionDetailsByTransactionIDRIBSDVout


class TestGetTransactionDetailsByTransactionIDRIBSDVout(unittest.TestCase):
    """GetTransactionDetailsByTransactionIDRIBSDVout unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetTransactionDetailsByTransactionIDRIBSDVout(self):
        """Test GetTransactionDetailsByTransactionIDRIBSDVout"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetTransactionDetailsByTransactionIDRIBSDVout()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from cryptoapis.api_client import ApiClient, Endpoint as _Endpoint
from cryptoapis.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from cryptoapis.model.feature_mainnets_not_allowed_for_plan import FeatureMainnetsNotAllowedForPlan
from cryptoapis.model.get_latest_mined_xrp_ripple_block_r import GetLatestMinedXRPRippleBlockR
from cryptoapis.model.get_xrp_ripple_address_details_r import GetXRPRippleAddressDetailsR
from cryptoapis.model.get_xrp_ripple_block_details_by_block_hash_r import GetXRPRippleBlockDetailsByBlockHashR
from cryptoapis.model.get_xrp_ripple_block_details_by_block_height_r import GetXRPRippleBlockDetailsByBlockHeightR
from cryptoapis.model.get_xrp_ripple_transaction_details_by_transaction_idr import GetXRPRippleTransactionDetailsByTransactionIDR
from cryptoapis.model.insufficient_credits import InsufficientCredits
from cryptoapis.model.invalid_api_key import InvalidApiKey
from cryptoapis.model.invalid_data import InvalidData
from cryptoapis.model.invalid_pagination import InvalidPagination
from cryptoapis.model.invalid_request_body_structure import InvalidRequestBodyStructure
from cryptoapis.model.list_xrp_ripple_transactions_by_address_r import ListXRPRippleTransactionsByAddressR
from cryptoapis.model.list_xrp_ripple_transactions_by_block_hash_r import ListXRPRippleTransactionsByBlockHashR
from cryptoapis.model.list_xrp_ripple_transactions_by_block_height_r import ListXRPRippleTransactionsByBlockHeightR
from cryptoapis.model.request_limit_reached import RequestLimitReached
from cryptoapis.model.resource_not_found import ResourceNotFound
from cryptoapis.model.unexpected_server_error import UnexpectedServerError
from cryptoapis.model.unsupported_media_type import UnsupportedMediaType


class XRPRippleApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        def __get_latest_mined_xrp__ripple_block(
            self,
            network,
            **kwargs
        ):
            """Get Latest Mined XRP (Ripple) Block  # noqa: E501

            Through this endpoint customers can fetch the last mined XRP block in the blockchain, along with its details. These could include the hash of the specific, the previous and the next block, its transactions count, its height, etc.     Since XRP is a different blockchain than Bitcoin and Ethereum, it isn't unified.  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_latest_mined_xrp__ripple_block(network, async_req=True)
            >>> result = thread.get()

            Args:
                network (str): Represents the name of the blockchain network used; blockchain networks are usually identical as technology and software, but they differ in data, e.g. - \"mainnet\" is the live network with actual data while networks like \"testnet\", \"ropsten\", \"rinkeby\" are test networks.

            Keyword Args:
                context (str): In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. `context` is specified by the user.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                GetLatestMinedXRPRippleBlockR
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['network'] = \
                network
            return self.call_with_http_info(**kwargs)

        self.get_latest_mined_xrp__ripple_block = _Endpoint(
            settings={
                'response_type': (GetLatestMinedXRPRippleBlockR,),
                'auth': [
                    'ApiKey'
                ],
                'endpoint_path': '/blockchain-data/xrp-specific/{network}/blocks/last',
                'operation_id': 'get_latest_mined_xrp__ripple_block',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'network',
                    'context',
                ],
                'required': [
                    'network',
                ],
                'nullable': [
                ],
                'enum': [
                    'network',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('network',): {

                        "MAINNET": "mainnet",
                        "TESTNET": "testnet"
                    },
                },
                'openapi_types': {
                    'network':
                        (str,),
                    'context':
                        (str,),
                },
                'attribute_map': {
                    'network': 'network',
                    'context': 'context',
                },
                'location_map': {
                    'network': 'path',
                    'context': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_latest_mined_xrp__ripple_block
        )

        def __get_xrp__ripple_address_details(
            self,
            network,
            address,
            **kwargs
        ):
            """Get XRP (Ripple) Address Details  # noqa: E501

            Through this endpoint the customer can receive basic information about a given XRP address based on confirmed/synced blocks only. In the case where there are any incoming or outgoing **unconfirmed** transactions for the specific address, they **will not** be counted or calculated here.    Since XRP is a different blockchain than Bitcoin and Ethereum, it isn't unified.  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_xrp__ripple_address_details(network, address, async_req=True)
            >>> result = thread.get()

            Args:
                network (str): Represents the name of the blockchain network used; blockchain networks are usually identical as technology and software, but they differ in data, e.g. - \"mainnet\" is the live network with actual data while networks like \"testnet\",  are test networks.
                address (str): Represents the public address, which is a compressed and shortened form of a public key.

            Keyword Args:
                context (str): In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. `context` is specified by the user.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                GetXRPRippleAddressDetailsR
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['network'] = \
                network
            kwargs['address'] = \
                address
            return self.call_with_http_info(**kwargs)

        self.get_xrp__ripple_address_details = _Endpoint(
            settings={
                'response_type': (GetXRPRippleAddressDetailsR,),
                'auth': [
                    'ApiKey'
                ],
                'endpoint_path': '/blockchain-data/xrp-specific/{network}/addresses/{address}',
                'operation_id': 'get_xrp__ripple_address_details',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'network',
                    'address',
                    'context',
                ],
                'required': [
                    'network',
                    'address',
                ],
                'nullable': [
                ],
                'enum': [
                    'network',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('network',): {

                        "MAINNET": "mainnet",
                        "TESTNET": "testnet"
                    },
                },
                'openapi_types': {
                    'network':
                        (str,),
                    'address':
                        (str,),
                    'context':
                        (str,),
                },
                'attribute_map': {
                    'network': 'network',
                    'address': 'address',
                    'context': 'context',
                },
                'location_map': {
                    'network': 'path',
                    'address': 'path',
                    'context': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_xrp__ripple_address_details
        )

        def __get_xrp__ripple_block_details_by_block_hash(
            self,
            network,
            block_hash,
            **kwargs
        ):
            """Get XRP (Ripple) Block Details By Block Hash  # noqa: E501

            Through this endpoint customers can obtain basic information about a given XRP block (a block on the XRP blockchain), specifically by using the `hash` parameter. These block details could include the hash of the specific, the previous and the next block, the number of included transactions, etc.     Since XRP is a different blockchain than Bitcoin and Ethereum, it isn't unified.  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_xrp__ripple_block_details_by_block_hash(network, block_hash, async_req=True)
            >>> result = thread.get()

            Args:
                network (str): Represents the name of the blockchain network used; blockchain networks are usually identical as technology and software, but they differ in data, e.g. - \"mainnet\" is the live network with actual data while networks like \"testnet\",  are test networks.
                block_hash (str): Represents the hash of the block, which is its unique identifier. It represents a cryptographic digital fingerprint made by hashing the block header twice through the SHA256 algorithm.

            Keyword Args:
                context (str): In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. `context` is specified by the user.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                GetXRPRippleBlockDetailsByBlockHashR
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['network'] = \
                network
            kwargs['block_hash'] = \
                block_hash
            return self.call_with_http_info(**kwargs)

        self.get_xrp__ripple_block_details_by_block_hash = _Endpoint(
            settings={
                'response_type': (GetXRPRippleBlockDetailsByBlockHashR,),
                'auth': [
                    'ApiKey'
                ],
                'endpoint_path': '/blockchain-data/xrp-specific/{network}/blocks/hash/{blockHash}',
                'operation_id': 'get_xrp__ripple_block_details_by_block_hash',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'network',
                    'block_hash',
                    'context',
                ],
                'required': [
                    'network',
                    'block_hash',
                ],
                'nullable': [
                ],
                'enum': [
                    'network',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('network',): {

                        "MAINNET": "mainnet",
                        "TESTNET": "testnet"
                    },
                },
                'openapi_types': {
                    'network':
                        (str,),
                    'block_hash':
                        (str,),
                    'context':
                        (str,),
                },
                'attribute_map': {
                    'network': 'network',
                    'block_hash': 'blockHash',
                    'context': 'context',
                },
                'location_map': {
                    'network': 'path',
                    'block_hash': 'path',
                    'context': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_xrp__ripple_block_details_by_block_hash
        )

        def __get_xrp__ripple_block_details_by_block_height(
            self,
            network,
            block_height,
            **kwargs
        ):
            """Get XRP (Ripple) Block Details By Block Height  # noqa: E501

            Through this endpoint customers can obtain basic information about a given XRP block (a block on the XRP blockchain), specifically by using the `height` parameter. These block details could include the hash of the specific, the previous and the next block, its transactions count, etc.    Since XRP is a different blockchain than Bitcoin and Ethereum, it isn't unified.  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_xrp__ripple_block_details_by_block_height(network, block_height, async_req=True)
            >>> result = thread.get()

            Args:
                network (str): Represents the name of the blockchain network used; blockchain networks are usually identical as technology and software, but they differ in data, e.g. - \"mainnet\" is the live network with actual data while networks like \"testnet\",  are test networks.
                block_height (str): Represents the number of blocks in the blockchain preceding this specific block. Block numbers have no gaps. A blockchain usually starts with block 0 called the \"Genesis block\".

            Keyword Args:
                context (str): In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. `context` is specified by the user.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                GetXRPRippleBlockDetailsByBlockHeightR
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['network'] = \
                network
            kwargs['block_height'] = \
                block_height
            return self.call_with_http_info(**kwargs)

        self.get_xrp__ripple_block_details_by_block_height = _Endpoint(
            settings={
                'response_type': (GetXRPRippleBlockDetailsByBlockHeightR,),
                'auth': [
                    'ApiKey'
                ],
                'endpoint_path': '/blockchain-data/xrp-specific/{network}/blocks/height/{blockHeight}',
                'operation_id': 'get_xrp__ripple_block_details_by_block_height',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'network',
                    'block_height',
                    'context',
                ],
                'required': [
                    'network',
                    'block_height',
                ],
                'nullable': [
                ],
                'enum': [
                    'network',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('network',): {

                        "MAINNET": "mainnet",
                        "TESTNET": "testnet"
                    },
                },
                'openapi_types': {
                    'network':
                        (str,),
                    'block_height':
                        (str,),
                    'context':
                        (str,),
                },
                'attribute_map': {
                    'network': 'network',
                    'block_height': 'blockHeight',
                    'context': 'context',
                },
                'location_map': {
                    'network': 'path',
                    'block_height': 'path',
                    'context': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_xrp__ripple_block_details_by_block_height
        )

        def __get_xrp__ripple_transaction_details_by_transaction_id(
            self,
            network,
            transaction_hash,
            **kwargs
        ):
            """Get XRP (Ripple) Transaction Details By Transaction ID  # noqa: E501

            Through this endpoint customers can obtain details about a XRP transaction by the transaction's unique identifier.     Since XRP is a different blockchain than Bitcoin and Ethereum, it isn't unified.  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_xrp__ripple_transaction_details_by_transaction_id(network, transaction_hash, async_req=True)
            >>> result = thread.get()

            Args:
                network (str): Represents the name of the blockchain network used; blockchain networks are usually identical as technology and software, but they differ in data, e.g. - \"mainnet\" is the live network with actual data while networks like \"testnet\", \"ropsten\", \"rinkeby\" are test networks.
                transaction_hash (str): Represents the same as `transactionId` for account-based protocols like Ethereum, while it could be different in UTXO-based protocols like Bitcoin. E.g., in UTXO-based protocols `hash` is different from `transactionId` for SegWit transactions.

            Keyword Args:
                context (str): In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. `context` is specified by the user.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                GetXRPRippleTransactionDetailsByTransactionIDR
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['network'] = \
                network
            kwargs['transaction_hash'] = \
                transaction_hash
            return self.call_with_http_info(**kwargs)

        self.get_xrp__ripple_transaction_details_by_transaction_id = _Endpoint(
            settings={
                'response_type': (GetXRPRippleTransactionDetailsByTransactionIDR,),
                'auth': [
                    'ApiKey'
                ],
                'endpoint_path': '/blockchain-data/xrp-specific/{network}/transactions/{transactionHash}',
                'operation_id': 'get_xrp__ripple_transaction_details_by_transaction_id',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'network',
                    'transaction_hash',
                    'context',
                ],
                'required': [
                    'network',
                    'transaction_hash',
                ],
                'nullable': [
                ],
                'enum': [
                    'network',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('network',): {

                        "MAINNET": "mainnet",
                        "TESTNET": "testnet"
                    },
                },
                'openapi_types': {
                    'network':
                        (str,),
                    'transaction_hash':
                        (str,),
                    'context':
                        (str,),
                },
                'attribute_map': {
                    'network': 'network',
                    'transaction_hash': 'transactionHash',
                    'context': 'context',
                },
                'location_map': {
                    'network': 'path',
                    'transaction_hash': 'path',
                    'context': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_xrp__ripple_transaction_details_by_transaction_id
        )

        def __list_xrp__ripple_transactions_by_address(
            self,
            network,
            address,
            **kwargs
        ):
            """List XRP (Ripple) Transactions by Address  # noqa: E501

            This endpoint will list XRP transactions by a attribute `address`. The transactions listed will detail additional information such as hash, height, time of creation in Unix timestamp, etc.    Since XRP is a different blockchain than Bitcoin and Ethereum, it isn't unified.    {note}Please note that listing data from the same type will apply pagination on the results.{/note}  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.list_xrp__ripple_transactions_by_address(network, address, async_req=True)
            >>> result = thread.get()

            Args:
                network (str): Represents the name of the blockchain network used; blockchain networks are usually identical as technology and software, but they differ in data, e.g. - \"mainnet\" is the live network with actual data while networks like \"testnet\",  are test networks.
                address (str): Represents the public address, which is a compressed and shortened form of a public key.

            Keyword Args:
                context (str): In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. `context` is specified by the user.. [optional]
                limit (int): Defines how many items should be returned in the response per page basis.. [optional] if omitted the server will use the default value of 50
                offset (int): The starting index of the response items, i.e. where the response should start listing the returned items.. [optional] if omitted the server will use the default value of 0
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ListXRPRippleTransactionsByAddressR
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['network'] = \
                network
            kwargs['address'] = \
                address
            return self.call_with_http_info(**kwargs)

        self.list_xrp__ripple_transactions_by_address = _Endpoint(
            settings={
                'response_type': (ListXRPRippleTransactionsByAddressR,),
                'auth': [
                    'ApiKey'
                ],
                'endpoint_path': '/blockchain-data/xrp-specific/{network}/addresses/{address}/transactions',
                'operation_id': 'list_xrp__ripple_transactions_by_address',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'network',
                    'address',
                    'context',
                    'limit',
                    'offset',
                ],
                'required': [
                    'network',
                    'address',
                ],
                'nullable': [
                ],
                'enum': [
                    'network',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('network',): {

                        "MAINNET": "mainnet",
                        "TESTNET": "testnet"
                    },
                },
                'openapi_types': {
                    'network':
                        (str,),
                    'address':
                        (str,),
                    'context':
                        (str,),
                    'limit':
                        (int,),
                    'offset':
                        (int,),
                },
                'attribute_map': {
                    'network': 'network',
                    'address': 'address',
                    'context': 'context',
                    'limit': 'limit',
                    'offset': 'offset',
                },
                'location_map': {
                    'network': 'path',
                    'address': 'path',
                    'context': 'query',
                    'limit': 'query',
                    'offset': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__list_xrp__ripple_transactions_by_address
        )

        def __list_xrp__ripple_transactions_by_block_hash(
            self,
            network,
            block_hash,
            **kwargs
        ):
            """List XRP (Ripple) Transactions By Block Hash  # noqa: E501

            This endpoint will list transactions by an attribute `blockHash`. The transactions listed will detail additional information such as hash, addresses, time of creation in Unix timestamp, etc.    Since XRP is a different blockchain than Bitcoin and Ethereum, it isn't unified.    {note}Please note that listing data from the same type will apply pagination on the results.{/note}  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.list_xrp__ripple_transactions_by_block_hash(network, block_hash, async_req=True)
            >>> result = thread.get()

            Args:
                network (str): Represents the name of the blockchain network used; blockchain networks are usually identical as technology and software, but they differ in data, e.g. - \"mainnet\" is the live network with actual data while networks like \"testnet\", \"ropsten\", \"rinkeby\" are test networks.
                block_hash (str): Represents the hash of the block, which is its unique identifier. It represents a cryptographic digital fingerprint made by hashing the block header twice through the SHA256 algorithm.

            Keyword Args:
                context (str): In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. `context` is specified by the user.. [optional]
                limit (int): Defines how many items should be returned in the response per page basis.. [optional] if omitted the server will use the default value of 50
                offset (int): The starting index of the response items, i.e. where the response should start listing the returned items.. [optional] if omitted the server will use the default value of 0
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ListXRPRippleTransactionsByBlockHashR
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['network'] = \
                network
            kwargs['block_hash'] = \
                block_hash
            return self.call_with_http_info(**kwargs)

        self.list_xrp__ripple_transactions_by_block_hash = _Endpoint(
            settings={
                'response_type': (ListXRPRippleTransactionsByBlockHashR,),
                'auth': [
                    'ApiKey'
                ],
                'endpoint_path': '/blockchain-data/xrp-specific/{network}/blocks/hash/{blockHash}/transactions',
                'operation_id': 'list_xrp__ripple_transactions_by_block_hash',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'network',
                    'block_hash',
                    'context',
                    'limit',
                    'offset',
                ],
                'required': [
                    'network',
                    'block_hash',
                ],
                'nullable': [
                ],
                'enum': [
                    'network',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('network',): {

                        "MAINNET": "mainnet",
                        "TESTNET": "testnet"
                    },
                },
                'openapi_types': {
                    'network':
                        (str,),
                    'block_hash':
                        (str,),
                    'context':
                        (str,),
                    'limit':
                        (int,),
                    'offset':
                        (int,),
                },
                'attribute_map': {
                    'network': 'network',
                    'block_hash': 'blockHash',
                    'context': 'context',
                    'limit': 'limit',
                    'offset': 'offset',
                },
                'location_map': {
                    'network': 'path',
                    'block_hash': 'path',
                    'context': 'query',
                    'limit': 'query',
                    'offset': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__list_xrp__ripple_transactions_by_block_hash
        )

        def __list_xrp__ripple_transactions_by_block_height(
            self,
            network,
            block_height,
            **kwargs
        ):
            """List XRP (Ripple) Transactions By Block Height  # noqa: E501

            This endpoint will list transactions by an attribute `blockHeight`. The transactions listed will detail additional information such as hash, addresses, time of creation in Unix timestamp, etc.    Since XRP is a different blockchain than Bitcoin and Ethereum, it isn't unified.    {note}Please note that listing data from the same type will apply pagination on the results.{/note}  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.list_xrp__ripple_transactions_by_block_height(network, block_height, async_req=True)
            >>> result = thread.get()

            Args:
                network (str): Represents the name of the blockchain network used; blockchain networks are usually identical as technology and software, but they differ in data, e.g. - \"mainnet\" is the live network with actual data while networks like \"testnet\", \"ropsten\", \"rinkeby\" are test networks.
                block_height (int):

            Keyword Args:
                context (str): In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. `context` is specified by the user.. [optional]
                limit (int): Defines how many items should be returned in the response per page basis.. [optional] if omitted the server will use the default value of 50
                offset (int): The starting index of the response items, i.e. where the response should start listing the returned items.. [optional] if omitted the server will use the default value of 0
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ListXRPRippleTransactionsByBlockHeightR
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['network'] = \
                network
            kwargs['block_height'] = \
                block_height
            return self.call_with_http_info(**kwargs)

        self.list_xrp__ripple_transactions_by_block_height = _Endpoint(
            settings={
                'response_type': (ListXRPRippleTransactionsByBlockHeightR,),
                'auth': [
                    'ApiKey'
                ],
                'endpoint_path': '/blockchain-data/xrp-specific/{network}/blocks/height/{blockHeight}/transactions',
                'operation_id': 'list_xrp__ripple_transactions_by_block_height',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'network',
                    'block_height',
                    'context',
                    'limit',
                    'offset',
                ],
                'required': [
                    'network',
                    'block_height',
                ],
                'nullable': [
                ],
                'enum': [
                    'network',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('network',): {

                        "MAINNET": "mainnet",
                        "TESTNET": "testnet"
                    },
                },
                'openapi_types': {
                    'network':
                        (str,),
                    'block_height':
                        (int,),
                    'context':
                        (str,),
                    'limit':
                        (int,),
                    'offset':
                        (int,),
                },
                'attribute_map': {
                    'network': 'network',
                    'block_height': 'blockHeight',
                    'context': 'context',
                    'limit': 'limit',
                    'offset': 'offset',
                },
                'location_map': {
                    'network': 'path',
                    'block_height': 'path',
                    'context': 'query',
                    'limit': 'query',
                    'offset': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__list_xrp__ripple_transactions_by_block_height
        )



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.list_transactions_by_address_ribsb import ListTransactionsByAddressRIBSB
from cryptoapis.model.list_transactions_by_address_ribsbc import ListTransactionsByAddressRIBSBC
from cryptoapis.model.list_transactions_by_address_ribsd import ListTransactionsByAddressRIBSD
from cryptoapis.model.list_transactions_by_address_ribsd2 import ListTransactionsByAddressRIBSD2
from cryptoapis.model.list_transactions_by_address_ribsd2_vin import ListTransactionsByAddressRIBSD2Vin
from cryptoapis.model.list_transactions_by_address_ribsd2_vout import ListTransactionsByAddressRIBSD2Vout
from cryptoapis.model.list_transactions_by_address_ribse import ListTransactionsByAddressRIBSE
from cryptoapis.model.list_transactions_by_address_ribse_gas_price import ListTransactionsByAddressRIBSEGasPrice
from cryptoapis.model.list_transactions_by_address_ribsec import ListTransactionsByAddressRIBSEC
from cryptoapis.model.list_transactions_by_address_ribsl import ListTransactionsByAddressRIBSL
globals()['ListTransactionsByAddressRIBSB'] = ListTransactionsByAddressRIBSB
globals()['ListTransactionsByAddressRIBSBC'] = ListTransactionsByAddressRIBSBC
globals()['ListTransactionsByAddressRIBSD'] = ListTransactionsByAddressRIBSD
globals()['ListTransactionsByAddressRIBSD2'] = ListTransactionsByAddressRIBSD2
globals()['ListTransactionsByAddressRIBSD2Vin'] = ListTransactionsByAddressRIBSD2Vin
globals()['ListTransactionsByAddressRIBSD2Vout'] = ListTransactionsByAddressRIBSD2Vout
globals()['ListTransactionsByAddressRIBSE'] = ListTransactionsByAddressRIBSE
globals()['ListTransactionsByAddressRIBSEC'] = ListTransactionsByAddressRIBSEC
globals()['ListTransactionsByAddressRIBSEGasPrice'] = ListTransactionsByAddressRIBSEGasPrice
globals()['ListTransactionsByAddressRIBSL'] = ListTransactionsByAddressRIBSL
from cryptoapis.model.list_transactions_by_address_ribs import ListTransactionsByAddressRIBS


class TestListTransactionsByAddressRIBS(unittest.TestCase):
    """ListTransactionsByAddressRIBS unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListTransactionsByAddressRIBS(self):
        """Test ListTransactionsByAddressRIBS"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListTransactionsByAddressRIBS()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_xrp_ripple_transaction_details_by_transaction_idri_fee import GetXRPRippleTransactionDetailsByTransactionIDRIFee
from cryptoapis.model.get_xrp_ripple_transaction_details_by_transaction_idri_offer import GetXRPRippleTransactionDetailsByTransactionIDRIOffer
from cryptoapis.model.get_xrp_ripple_transaction_details_by_transaction_idri_receive import GetXRPRippleTransactionDetailsByTransactionIDRIReceive
from cryptoapis.model.get_xrp_ripple_transaction_details_by_transaction_idri_recipients import GetXRPRippleTransactionDetailsByTransactionIDRIRecipients
from cryptoapis.model.get_xrp_ripple_transaction_details_by_transaction_idri_senders import GetXRPRippleTransactionDetailsByTransactionIDRISenders
from cryptoapis.model.get_xrp_ripple_transaction_details_by_transaction_idri_value import GetXRPRippleTransactionDetailsByTransactionIDRIValue
globals()['GetXRPRippleTransactionDetailsByTransactionIDRIFee'] = GetXRPRippleTransactionDetailsByTransactionIDRIFee
globals()['GetXRPRippleTransactionDetailsByTransactionIDRIOffer'] = GetXRPRippleTransactionDetailsByTransactionIDRIOffer
globals()['GetXRPRippleTransactionDetailsByTransactionIDRIReceive'] = GetXRPRippleTransactionDetailsByTransactionIDRIReceive
globals()['GetXRPRippleTransactionDetailsByTransactionIDRIRecipients'] = GetXRPRippleTransactionDetailsByTransactionIDRIRecipients
globals()['GetXRPRippleTransactionDetailsByTransactionIDRISenders'] = GetXRPRippleTransactionDetailsByTransactionIDRISenders
globals()['GetXRPRippleTransactionDetailsByTransactionIDRIValue'] = GetXRPRippleTransactionDetailsByTransactionIDRIValue
from cryptoapis.model.get_xrp_ripple_transaction_details_by_transaction_idri import GetXRPRippleTransactionDetailsByTransactionIDRI


class TestGetXRPRippleTransactionDetailsByTransactionIDRI(unittest.TestCase):
    """GetXRPRippleTransactionDetailsByTransactionIDRI unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetXRPRippleTransactionDetailsByTransactionIDRI(self):
        """Test GetXRPRippleTransactionDetailsByTransactionIDRI"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetXRPRippleTransactionDetailsByTransactionIDRI()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.tokens_forwarding_success_ethereumerc20token import TokensForwardingSuccessEthereumerc20token
from cryptoapis.model.tokens_forwarding_success_ethereumerc721token import TokensForwardingSuccessEthereumerc721token
from cryptoapis.model.tokens_forwarding_success_omnilayertoken import TokensForwardingSuccessOmnilayertoken
globals()['TokensForwardingSuccessEthereumerc20token'] = TokensForwardingSuccessEthereumerc20token
globals()['TokensForwardingSuccessEthereumerc721token'] = TokensForwardingSuccessEthereumerc721token
globals()['TokensForwardingSuccessOmnilayertoken'] = TokensForwardingSuccessOmnilayertoken
from cryptoapis.model.tokens_forwarding_success_token import TokensForwardingSuccessToken


class TestTokensForwardingSuccessToken(unittest.TestCase):
    """TokensForwardingSuccessToken unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTokensForwardingSuccessToken(self):
        """Test TokensForwardingSuccessToken"""
        # FIXME: construct object with mandatory attributes with example values
        # model = TokensForwardingSuccessToken()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from cryptoapis.api_client import ApiClient, Endpoint as _Endpoint
from cryptoapis.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from cryptoapis.model.feature_mainnets_not_allowed_for_plan import FeatureMainnetsNotAllowedForPlan
from cryptoapis.model.insufficient_credits import InsufficientCredits
from cryptoapis.model.invalid_api_key import InvalidApiKey
from cryptoapis.model.invalid_data import InvalidData
from cryptoapis.model.invalid_pagination import InvalidPagination
from cryptoapis.model.invalid_request_body_structure import InvalidRequestBodyStructure
from cryptoapis.model.list_assets_details_r import ListAssetsDetailsR
from cryptoapis.model.request_limit_reached import RequestLimitReached
from cryptoapis.model.unexpected_server_error import UnexpectedServerError
from cryptoapis.model.unsupported_media_type import UnsupportedMediaType


class AssetsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        def __list_assets_details(
            self,
            **kwargs
        ):
            """List Assets Details  # noqa: E501

            This endpoint will return details on a requested asset. The asset could be a cryptocurrency or FIAT asset that we support. Each asset has a unique identifier - `assetId` and a unique symbol in the form of a string, e.g. \"BTC\".    The details returned could include information on the latest rate and rate fluctuation of different periods of time - 24 hours, a week, one hour, the encoding of the logo, and more.    {note}Please note that listing data from the same type will apply pagination on the results.{/note}  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.list_assets_details(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                context (str): In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. `context` is specified by the user.. [optional]
                asset_type (str): Defines the type of the supported asset. This could be either \"crypto\" or \"fiat\".. [optional]
                crypto_type (str): Subtype of the crypto assets. Could be COIN or TOKEN. [optional]
                limit (int): Defines how many items should be returned in the response per page basis.. [optional] if omitted the server will use the default value of 50
                offset (int): The starting index of the response items, i.e. where the response should start listing the returned items.. [optional] if omitted the server will use the default value of 0
                waas_enabled (bool): Show only if WaaS is/not enabled. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ListAssetsDetailsR
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.list_assets_details = _Endpoint(
            settings={
                'response_type': (ListAssetsDetailsR,),
                'auth': [
                    'ApiKey'
                ],
                'endpoint_path': '/market-data/assets/details',
                'operation_id': 'list_assets_details',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'context',
                    'asset_type',
                    'crypto_type',
                    'limit',
                    'offset',
                    'waas_enabled',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                    'asset_type',
                    'crypto_type',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('asset_type',): {

                        "FIAT": "fiat",
                        "CRYPTO": "crypto"
                    },
                    ('crypto_type',): {

                        "COIN": "coin",
                        "TOKEN": "token"
                    },
                },
                'openapi_types': {
                    'context':
                        (str,),
                    'asset_type':
                        (str,),
                    'crypto_type':
                        (str,),
                    'limit':
                        (int,),
                    'offset':
                        (int,),
                    'waas_enabled':
                        (bool,),
                },
                'attribute_map': {
                    'context': 'context',
                    'asset_type': 'assetType',
                    'crypto_type': 'cryptoType',
                    'limit': 'limit',
                    'offset': 'offset',
                    'waas_enabled': 'waasEnabled',
                },
                'location_map': {
                    'context': 'query',
                    'asset_type': 'query',
                    'crypto_type': 'query',
                    'limit': 'query',
                    'offset': 'query',
                    'waas_enabled': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__list_assets_details
        )



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from cryptoapis.api_client import ApiClient, Endpoint as _Endpoint
from cryptoapis.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from cryptoapis.model.feature_mainnets_not_allowed_for_plan import FeatureMainnetsNotAllowedForPlan
from cryptoapis.model.get_wallet_asset_details_r import GetWalletAssetDetailsR
from cryptoapis.model.insufficient_credits import InsufficientCredits
from cryptoapis.model.invalid_api_key import InvalidApiKey
from cryptoapis.model.invalid_data import InvalidData
from cryptoapis.model.invalid_pagination import InvalidPagination
from cryptoapis.model.invalid_request_body_structure import InvalidRequestBodyStructure
from cryptoapis.model.list_receiving_addresses_r import ListReceivingAddressesR
from cryptoapis.model.list_supported_tokens_r import ListSupportedTokensR
from cryptoapis.model.request_limit_reached import RequestLimitReached
from cryptoapis.model.resource_not_found import ResourceNotFound
from cryptoapis.model.unexpected_server_error import UnexpectedServerError
from cryptoapis.model.unsupported_media_type import UnsupportedMediaType


class InformativeApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        def __get_wallet_asset_details(
            self,
            blockchain,
            network,
            wallet_id,
            **kwargs
        ):
            """Get Wallet Asset Details  # noqa: E501

            Through this endpoint customers can obtain details about a specific Wallet/Vault.  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_wallet_asset_details(blockchain, network, wallet_id, async_req=True)
            >>> result = thread.get()

            Args:
                blockchain (str): Represents the specific blockchain protocol name, e.g. Ethereum, Bitcoin, etc.
                network (str): Represents the name of the blockchain network used; blockchain networks are usually identical as technology and software, but they differ in data, e.g. - \"mainnet\" is the live network with actual data while networks like \"testnet\", \"ropsten\", \"rinkeby\" are test networks.
                wallet_id (str): Defines the unique ID of the Wallet.

            Keyword Args:
                context (str): In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. `context` is specified by the user.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                GetWalletAssetDetailsR
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['blockchain'] = \
                blockchain
            kwargs['network'] = \
                network
            kwargs['wallet_id'] = \
                wallet_id
            return self.call_with_http_info(**kwargs)

        self.get_wallet_asset_details = _Endpoint(
            settings={
                'response_type': (GetWalletAssetDetailsR,),
                'auth': [
                    'ApiKey'
                ],
                'endpoint_path': '/wallet-as-a-service/wallets/{walletId}/{blockchain}/{network}',
                'operation_id': 'get_wallet_asset_details',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'blockchain',
                    'network',
                    'wallet_id',
                    'context',
                ],
                'required': [
                    'blockchain',
                    'network',
                    'wallet_id',
                ],
                'nullable': [
                ],
                'enum': [
                    'blockchain',
                    'network',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('blockchain',): {

                        "BITCOIN": "bitcoin",
                        "BITCOIN-CASH": "bitcoin-cash",
                        "LITECOIN": "litecoin",
                        "DOGECOIN": "dogecoin",
                        "DASH": "dash",
                        "ETHEREUM": "ethereum"
                    },
                    ('network',): {

                        "MAINNET": "mainnet",
                        "TESTNET": "testnet"
                    },
                },
                'openapi_types': {
                    'blockchain':
                        (str,),
                    'network':
                        (str,),
                    'wallet_id':
                        (str,),
                    'context':
                        (str,),
                },
                'attribute_map': {
                    'blockchain': 'blockchain',
                    'network': 'network',
                    'wallet_id': 'walletId',
                    'context': 'context',
                },
                'location_map': {
                    'blockchain': 'path',
                    'network': 'path',
                    'wallet_id': 'path',
                    'context': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_wallet_asset_details
        )

        def __list_receiving_addresses(
            self,
            blockchain,
            network,
            wallet_id,
            **kwargs
        ):
            """List Receiving Addresses  # noqa: E501

            Through this endpoint customers can pull a list of Deposit Addresses they have already generated. Deposit addresses are listed with their specific details such as unique ID.    {note}Please note that listing data from the same type will apply pagination on the results.{/note}  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.list_receiving_addresses(blockchain, network, wallet_id, async_req=True)
            >>> result = thread.get()

            Args:
                blockchain (str): Represents the specific blockchain protocol name, e.g. Ethereum, Bitcoin, etc.
                network (str): Represents the name of the blockchain network used; blockchain networks are usually identical as technology and software, but they differ in data, e.g. - \"mainnet\" is the live network with actual data while networks like \"testnet\", \"ropsten\", \"rinkeby\" are test networks.
                wallet_id (str): Represents the unique ID of the specific Wallet.

            Keyword Args:
                context (str): In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. `context` is specified by the user.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ListReceivingAddressesR
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['blockchain'] = \
                blockchain
            kwargs['network'] = \
                network
            kwargs['wallet_id'] = \
                wallet_id
            return self.call_with_http_info(**kwargs)

        self.list_receiving_addresses = _Endpoint(
            settings={
                'response_type': (ListReceivingAddressesR,),
                'auth': [
                    'ApiKey'
                ],
                'endpoint_path': '/wallet-as-a-service/wallets/{walletId}/{blockchain}/{network}/addresses',
                'operation_id': 'list_receiving_addresses',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'blockchain',
                    'network',
                    'wallet_id',
                    'context',
                ],
                'required': [
                    'blockchain',
                    'network',
                    'wallet_id',
                ],
                'nullable': [
                ],
                'enum': [
                    'blockchain',
                    'network',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('blockchain',): {

                        "BITCOIN": "bitcoin",
                        "BITCOIN-CASH": "bitcoin-cash",
                        "LITECOIN": "litecoin",
                        "DOGECOIN": "dogecoin",
                        "DASH": "dash",
                        "ETHEREUM": "ethereum"
                    },
                    ('network',): {

                        "MAINNET": "mainnet",
                        "TESTNET": "testnet"
                    },
                },
                'openapi_types': {
                    'blockchain':
                        (str,),
                    'network':
                        (str,),
                    'wallet_id':
                        (str,),
                    'context':
                        (str,),
                },
                'attribute_map': {
                    'blockchain': 'blockchain',
                    'network': 'network',
                    'wallet_id': 'walletId',
                    'context': 'context',
                },
                'location_map': {
                    'blockchain': 'path',
                    'network': 'path',
                    'wallet_id': 'path',
                    'context': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__list_receiving_addresses
        )

        def __list_supported_tokens(
            self,
            blockchain,
            network,
            **kwargs
        ):
            """List Supported Tokens  # noqa: E501

            Through this endpoint customers can obtain information on multiple tokens at once.     {note}Please note that listing data from the same type will apply pagination on the results.{/note}  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.list_supported_tokens(blockchain, network, async_req=True)
            >>> result = thread.get()

            Args:
                blockchain (str): Represents the specific blockchain protocol name, e.g. Ethereum, Bitcoin, etc.
                network (str): Represents the name of the blockchain network used; blockchain networks are usually identical as technology and software, but they differ in data, e.g. - \"mainnet\" is the live network with actual data while networks like \"testnet\", \"ropsten\", \"rinkeby\" are test networks.

            Keyword Args:
                context (str): In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. `context` is specified by the user.. [optional]
                limit (int): Defines how many items should be returned in the response per page basis.. [optional] if omitted the server will use the default value of 50
                offset (int): The starting index of the response items, i.e. where the response should start listing the returned items.. [optional] if omitted the server will use the default value of 0
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ListSupportedTokensR
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['blockchain'] = \
                blockchain
            kwargs['network'] = \
                network
            return self.call_with_http_info(**kwargs)

        self.list_supported_tokens = _Endpoint(
            settings={
                'response_type': (ListSupportedTokensR,),
                'auth': [
                    'ApiKey'
                ],
                'endpoint_path': '/wallet-as-a-service/info/{blockchain}/{network}/supported-tokens',
                'operation_id': 'list_supported_tokens',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'blockchain',
                    'network',
                    'context',
                    'limit',
                    'offset',
                ],
                'required': [
                    'blockchain',
                    'network',
                ],
                'nullable': [
                ],
                'enum': [
                    'blockchain',
                    'network',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('blockchain',): {

                        "BITCOIN": "bitcoin",
                        "BITCOIN-CASH": "bitcoin-cash",
                        "LITECOIN": "litecoin",
                        "DOGECOIN": "dogecoin",
                        "DASH": "dash",
                        "ETHEREUM": "ethereum",
                        "ETHEREUM-CLASSIC": "ethereum-classic",
                        "XRP": "xrp"
                    },
                    ('network',): {

                        "MAINNET": "mainnet",
                        "TESTNET": "testnet",
                        "ROPSTEN": "ropsten",
                        "RINKEBY": "rinkeby",
                        "MORDOR": "mordor"
                    },
                },
                'openapi_types': {
                    'blockchain':
                        (str,),
                    'network':
                        (str,),
                    'context':
                        (str,),
                    'limit':
                        (int,),
                    'offset':
                        (int,),
                },
                'attribute_map': {
                    'blockchain': 'blockchain',
                    'network': 'network',
                    'context': 'context',
                    'limit': 'limit',
                    'offset': 'offset',
                },
                'location_map': {
                    'blockchain': 'path',
                    'network': 'path',
                    'context': 'query',
                    'limit': 'query',
                    'offset': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__list_supported_tokens
        )



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.list_transactions_by_block_hash_ribsb import ListTransactionsByBlockHashRIBSB
from cryptoapis.model.list_transactions_by_block_hash_ribsbc import ListTransactionsByBlockHashRIBSBC
from cryptoapis.model.list_transactions_by_block_hash_ribsd import ListTransactionsByBlockHashRIBSD
from cryptoapis.model.list_transactions_by_block_hash_ribsd2 import ListTransactionsByBlockHashRIBSD2
from cryptoapis.model.list_transactions_by_block_hash_ribsd2_vin import ListTransactionsByBlockHashRIBSD2Vin
from cryptoapis.model.list_transactions_by_block_hash_ribsd2_vout import ListTransactionsByBlockHashRIBSD2Vout
from cryptoapis.model.list_transactions_by_block_hash_ribse import ListTransactionsByBlockHashRIBSE
from cryptoapis.model.list_transactions_by_block_hash_ribse_gas_price import ListTransactionsByBlockHashRIBSEGasPrice
from cryptoapis.model.list_transactions_by_block_hash_ribsec import ListTransactionsByBlockHashRIBSEC
from cryptoapis.model.list_transactions_by_block_hash_ribsl import ListTransactionsByBlockHashRIBSL
globals()['ListTransactionsByBlockHashRIBSB'] = ListTransactionsByBlockHashRIBSB
globals()['ListTransactionsByBlockHashRIBSBC'] = ListTransactionsByBlockHashRIBSBC
globals()['ListTransactionsByBlockHashRIBSD'] = ListTransactionsByBlockHashRIBSD
globals()['ListTransactionsByBlockHashRIBSD2'] = ListTransactionsByBlockHashRIBSD2
globals()['ListTransactionsByBlockHashRIBSD2Vin'] = ListTransactionsByBlockHashRIBSD2Vin
globals()['ListTransactionsByBlockHashRIBSD2Vout'] = ListTransactionsByBlockHashRIBSD2Vout
globals()['ListTransactionsByBlockHashRIBSE'] = ListTransactionsByBlockHashRIBSE
globals()['ListTransactionsByBlockHashRIBSEC'] = ListTransactionsByBlockHashRIBSEC
globals()['ListTransactionsByBlockHashRIBSEGasPrice'] = ListTransactionsByBlockHashRIBSEGasPrice
globals()['ListTransactionsByBlockHashRIBSL'] = ListTransactionsByBlockHashRIBSL
from cryptoapis.model.list_transactions_by_block_hash_ribs import ListTransactionsByBlockHashRIBS


class TestListTransactionsByBlockHashRIBS(unittest.TestCase):
    """ListTransactionsByBlockHashRIBS unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListTransactionsByBlockHashRIBS(self):
        """Test ListTransactionsByBlockHashRIBS"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListTransactionsByBlockHashRIBS()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import unittest

import cryptoapis
from cryptoapis.api.create_subscriptions_for_api import CreateSubscriptionsForApi  # noqa: E501


class TestCreateSubscriptionsForApi(unittest.TestCase):
    """CreateSubscriptionsForApi unit test stubs"""

    def setUp(self):
        self.api = CreateSubscriptionsForApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_mined_transaction(self):
        """Test case for mined_transaction

        Mined transaction  # noqa: E501
        """
        pass

    def test_new_block(self):
        """Test case for new_block

        New Block  # noqa: E501
        """
        pass

    def test_new_confirmed_coins_transactions(self):
        """Test case for new_confirmed_coins_transactions

        New confirmed coins transactions  # noqa: E501
        """
        pass

    def test_new_confirmed_coins_transactions_and_each_confirmation(self):
        """Test case for new_confirmed_coins_transactions_and_each_confirmation

        New confirmed coins transactions and each confirmation  # noqa: E501
        """
        pass

    def test_new_confirmed_internal_transactions(self):
        """Test case for new_confirmed_internal_transactions

        New confirmed internal transactions  # noqa: E501
        """
        pass

    def test_new_confirmed_internal_transactions_and_each_confirmation(self):
        """Test case for new_confirmed_internal_transactions_and_each_confirmation

        New confirmed internal transactions and each confirmation  # noqa: E501
        """
        pass

    def test_new_confirmed_tokens_transactions(self):
        """Test case for new_confirmed_tokens_transactions

        New confirmed tokens transactions  # noqa: E501
        """
        pass

    def test_new_confirmed_tokens_transactions_and_each_confirmation(self):
        """Test case for new_confirmed_tokens_transactions_and_each_confirmation

        New confirmed tokens transactions and each confirmation  # noqa: E501
        """
        pass

    def test_new_unconfirmed_coins_transactions(self):
        """Test case for new_unconfirmed_coins_transactions

        New unconfirmed coins transactions  # noqa: E501
        """
        pass

    def test_new_unconfirmed_tokens_transactions(self):
        """Test case for new_unconfirmed_tokens_transactions

        New unconfirmed tokens transactions  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.add_tokens_to_existing_from_address_rb_token_data_bitcoin_omni_token import AddTokensToExistingFromAddressRBTokenDataBitcoinOmniToken
from cryptoapis.model.add_tokens_to_existing_from_address_rb_token_data_ethereum_erc20_token import AddTokensToExistingFromAddressRBTokenDataEthereumErc20Token
globals()['AddTokensToExistingFromAddressRBTokenDataBitcoinOmniToken'] = AddTokensToExistingFromAddressRBTokenDataBitcoinOmniToken
globals()['AddTokensToExistingFromAddressRBTokenDataEthereumErc20Token'] = AddTokensToExistingFromAddressRBTokenDataEthereumErc20Token
from cryptoapis.model.add_tokens_to_existing_from_address_rb_token_data import AddTokensToExistingFromAddressRBTokenData


class TestAddTokensToExistingFromAddressRBTokenData(unittest.TestCase):
    """AddTokensToExistingFromAddressRBTokenData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAddTokensToExistingFromAddressRBTokenData(self):
        """Test AddTokensToExistingFromAddressRBTokenData"""
        # FIXME: construct object with mandatory attributes with example values
        # model = AddTokensToExistingFromAddressRBTokenData()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_block_details_by_block_hash_ribsb import GetBlockDetailsByBlockHashRIBSB
from cryptoapis.model.get_block_details_by_block_hash_ribsbc import GetBlockDetailsByBlockHashRIBSBC
from cryptoapis.model.get_block_details_by_block_hash_ribsd import GetBlockDetailsByBlockHashRIBSD
from cryptoapis.model.get_block_details_by_block_hash_ribsd2 import GetBlockDetailsByBlockHashRIBSD2
from cryptoapis.model.get_block_details_by_block_hash_ribse import GetBlockDetailsByBlockHashRIBSE
from cryptoapis.model.get_block_details_by_block_hash_ribsec import GetBlockDetailsByBlockHashRIBSEC
from cryptoapis.model.get_block_details_by_block_hash_ribsl import GetBlockDetailsByBlockHashRIBSL
globals()['GetBlockDetailsByBlockHashRIBSB'] = GetBlockDetailsByBlockHashRIBSB
globals()['GetBlockDetailsByBlockHashRIBSBC'] = GetBlockDetailsByBlockHashRIBSBC
globals()['GetBlockDetailsByBlockHashRIBSD'] = GetBlockDetailsByBlockHashRIBSD
globals()['GetBlockDetailsByBlockHashRIBSD2'] = GetBlockDetailsByBlockHashRIBSD2
globals()['GetBlockDetailsByBlockHashRIBSE'] = GetBlockDetailsByBlockHashRIBSE
globals()['GetBlockDetailsByBlockHashRIBSEC'] = GetBlockDetailsByBlockHashRIBSEC
globals()['GetBlockDetailsByBlockHashRIBSL'] = GetBlockDetailsByBlockHashRIBSL
from cryptoapis.model.get_block_details_by_block_hash_ribs import GetBlockDetailsByBlockHashRIBS


class TestGetBlockDetailsByBlockHashRIBS(unittest.TestCase):
    """GetBlockDetailsByBlockHashRIBS unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetBlockDetailsByBlockHashRIBS(self):
        """Test GetBlockDetailsByBlockHashRIBS"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetBlockDetailsByBlockHashRIBS()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import unittest

import cryptoapis
from cryptoapis.api.unified_endpoints_api import UnifiedEndpointsApi  # noqa: E501


class TestUnifiedEndpointsApi(unittest.TestCase):
    """UnifiedEndpointsApi unit test stubs"""

    def setUp(self):
        self.api = UnifiedEndpointsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_address_details(self):
        """Test case for get_address_details

        Get Address Details  # noqa: E501
        """
        pass

    def test_get_block_details_by_block_hash(self):
        """Test case for get_block_details_by_block_hash

        Get Block Details By Block Hash  # noqa: E501
        """
        pass

    def test_get_block_details_by_block_height(self):
        """Test case for get_block_details_by_block_height

        Get Block Details By Block Height  # noqa: E501
        """
        pass

    def test_get_fee_recommendations(self):
        """Test case for get_fee_recommendations

        Get Fee Recommendations  # noqa: E501
        """
        pass

    def test_get_latest_mined_block(self):
        """Test case for get_latest_mined_block

        Get Latest Mined Block  # noqa: E501
        """
        pass

    def test_get_transaction_details_by_transaction_id(self):
        """Test case for get_transaction_details_by_transaction_id

        Get Transaction Details By Transaction ID  # noqa: E501
        """
        pass

    def test_list_transactions_by_address(self):
        """Test case for list_transactions_by_address

        List Transactions By Address  # noqa: E501
        """
        pass

    def test_list_transactions_by_block_hash(self):
        """Test case for list_transactions_by_block_hash

        List Transactions by Block Hash  # noqa: E501
        """
        pass

    def test_list_transactions_by_block_height(self):
        """Test case for list_transactions_by_block_height

        List Transactions by Block Height  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.delete_automatic_tokens_forwarding_ritsbot import DeleteAutomaticTokensForwardingRITSBOT
from cryptoapis.model.delete_automatic_tokens_forwarding_ritset import DeleteAutomaticTokensForwardingRITSET
globals()['DeleteAutomaticTokensForwardingRITSBOT'] = DeleteAutomaticTokensForwardingRITSBOT
globals()['DeleteAutomaticTokensForwardingRITSET'] = DeleteAutomaticTokensForwardingRITSET
from cryptoapis.model.delete_automatic_tokens_forwarding_rits import DeleteAutomaticTokensForwardingRITS


class TestDeleteAutomaticTokensForwardingRITS(unittest.TestCase):
    """DeleteAutomaticTokensForwardingRITS unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testDeleteAutomaticTokensForwardingRITS(self):
        """Test DeleteAutomaticTokensForwardingRITS"""
        # FIXME: construct object with mandatory attributes with example values
        # model = DeleteAutomaticTokensForwardingRITS()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.create_tokens_transaction_request_from_address_ri_recipients import CreateTokensTransactionRequestFromAddressRIRecipients
from cryptoapis.model.create_tokens_transaction_request_from_address_ri_senders import CreateTokensTransactionRequestFromAddressRISenders
from cryptoapis.model.create_tokens_transaction_request_from_address_ri_token_type_specific_data import CreateTokensTransactionRequestFromAddressRITokenTypeSpecificData
globals()['CreateTokensTransactionRequestFromAddressRIRecipients'] = CreateTokensTransactionRequestFromAddressRIRecipients
globals()['CreateTokensTransactionRequestFromAddressRISenders'] = CreateTokensTransactionRequestFromAddressRISenders
globals()['CreateTokensTransactionRequestFromAddressRITokenTypeSpecificData'] = CreateTokensTransactionRequestFromAddressRITokenTypeSpecificData
from cryptoapis.model.create_tokens_transaction_request_from_address_ri import CreateTokensTransactionRequestFromAddressRI


class TestCreateTokensTransactionRequestFromAddressRI(unittest.TestCase):
    """CreateTokensTransactionRequestFromAddressRI unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCreateTokensTransactionRequestFromAddressRI(self):
        """Test CreateTokensTransactionRequestFromAddressRI"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CreateTokensTransactionRequestFromAddressRI()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.create_coins_transaction_request_from_wallet_rb_data import CreateCoinsTransactionRequestFromWalletRBData
globals()['CreateCoinsTransactionRequestFromWalletRBData'] = CreateCoinsTransactionRequestFromWalletRBData
from cryptoapis.model.create_coins_transaction_request_from_wallet_rb import CreateCoinsTransactionRequestFromWalletRB


class TestCreateCoinsTransactionRequestFromWalletRB(unittest.TestCase):
    """CreateCoinsTransactionRequestFromWalletRB unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCreateCoinsTransactionRequestFromWalletRB(self):
        """Test CreateCoinsTransactionRequestFromWalletRB"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CreateCoinsTransactionRequestFromWalletRB()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
